#
# spec file for package perl-SNMP-Info
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-SNMP-Info
Version:        3.34
Release:        1.1
%define cpan_name SNMP-Info
Summary:        OO Interface to Network devices and MIBs through SNMP
License:        BSD-3-Clause
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/SNMP-Info/
Source0:        http://www.cpan.org/authors/id/O/OL/OLIVER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(SNMP)
Requires:       perl(SNMP)
%{perl_requires}

%description
SNMP::Info gives an object oriented interface to information obtained
through SNMP.

This module is geared towards network devices. Subclasses exist for a
number of network devices and common MIBs.

The idea behind this module is to give a common interface to data from
network devices, leaving the device-specific hacks behind the scenes in
subclasses.

In the SYNOPSIS example we fetch the name of all the ports on the device
and the duplex setting for that port with two methods -- interfaces() and
i_duplex().

The information may be coming from any number of MIB files and is very
vendor specific. SNMP::Info provides you a common method for all supported
devices.

Adding support for your own device is easy, and takes little SNMP
knowledge.

The module is not limited to network devices. Any MIB or device can be
given an objected oriented front-end by making a module that consists of a
couple hashes. See EXTENDING SNMP::INFO.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc ChangeLog COPYRIGHT DEVELOP DeviceMatrix.txt README

%changelog
* Mon Nov 21 2016 coolo@suse.com
- updated to 3.34
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
  version 3.34 (2016-11-20)
    [ENHANCEMENTS]
  * Support Cisco IPS Modules homed on the Cisco ASA (M. Kraus)
    [BUG FIXES]
  * Serial number on Nexus 9372 (genereic check for ID before using) (M. Caines)
* Thu May  5 2016 coolo@suse.com
- updated to 3.33
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
  version 3.33 (2016-04-27)
    [ENHANCEMENTS]
  * Move author-only tests to xt directory so they aren't run on installation
    by users
    [BUG FIXES]
  * Correct device serial number reporting for Cisco Nexus 5k switches with
    software version >= 7
  version 3.32 (2016-04-26)
    [ENHANCEMENTS]
  * Add 200 Mbps and 2.0 Gbps aliases to SPEED_MAP
  * Add Palo Alto support
  * Add VMware support
  * Support for propMultiplexor as ifType
  * Add device MAC to APC UPS
  * [#61] Report APC model for PDU products
  * Removed DeviceMatrix from the distribution
    [BUG FIXES]
  * Support undefined (noSuchInstance) values in Offline mode
  * Do not init table cache if Cache provided by user
  * Avoid deep recusion when AUTOLOAD and carp collide
  * Detect Cisco VG350s as L3 devices instead of APs
  * fix for 'Use of inherited AUTOLOAD for non-method SNMP::Info::Layer2::HP::agg_ports_ifstack() is deprecated'
  * Workaround in IPv6.pm to deal with possibly incorrect IPV6-MIB implementations
  * [#71] AUTOLOAD typo-catcher search for SNMP::Info no longer anchored
  * [#70] Respect version/comm/secname on passed Session obj
* Wed Jan 27 2016 coolo@suse.com
- updated to 3.31
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
  version 3.31 (2016-01-22)
    [ENHANCEMENTS]
  * Support for CiscoSB OS and Version (D. Tuecks)
  * SONMP support for Enhanced Topology Table
  * Add support for channelized interfaces in L3::Passport
    [BUG FIXES]
  * Correct link to MIB tarball
* Thu Nov 19 2015 coolo@suse.com
- updated to 3.30
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
  version 3.30 (2015-11-16)
    [ENHANCEMENTS]
  * RT #106254: Add new sysObjectID mapping for Ubiquiti
    [BUG FIXES]
  * Correct link to MIB tarball
  * Correct port indexing of newer VSP 4K and 8K in L3::Passport
  * Statistics in the sysIfxStatTable are 64-bit counters, so they should
    override the 64-bit methods.
* Fri Oct 16 2015 coolo@suse.com
- updated to 3.29
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
  version 3.29 (2015-10-13)
    [ENHANCEMENTS]
  * Add IPv6::ipv6_addr() method to map IPv6 interface address indexes to actual addresses
  * Add support for (remote) IPv6 addresses to LLDP::lldp_addr()
  * Add LLDP::lldp_ipv6() and LLDP::lldp_mac() so that remote management
    addresses of specific types can be requested
* Mon Sep 21 2015 coolo@suse.com
- updated to 3.28
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
  version 3.28 (2015-06-18)
    [ENHANCEMENTS]
  * Add Layer3::Huawei class for Huawei Quidway switches
  * Modified generic Layer3::Cisco class: use community based indexing if
    the device returns a value for vtpVersion
    [BUG FIXES]
  * Correct port indexing of VSP 4K in L3::Passport
  version 3.27 (2015-05-05)
    [ENHANCEMENTS]
  * Cisco Aironet PSU information
  * Only log adding mibdirs at debug level 2
    [BUG FIXES]
  * [#221] Drop Cisco Voice VLAN 4096
* Mon Apr 13 2015 coolo@suse.com
- updated to 3.26
  see /usr/share/doc/packages/perl-SNMP-Info/ChangeLog
* Sun May  1 2011 coolo@opensuse.org
- updated to 2.04, see Changes
* Mon Nov 29 2010 coolo@novell.com
- called spec2changelog
* Fri Nov  2 2007 jfunk@funktronics.ca
- Initial release
